# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IAppListArgs',
    'IAppListArgsDict',
    'IAppMetadataArgs',
    'IAppMetadataArgsDict',
    'IAppTableArgs',
    'IAppTableArgsDict',
    'IAppTableRowArgs',
    'IAppTableRowArgsDict',
    'IAppVariableArgs',
    'IAppVariableArgsDict',
]

MYPY = False

if not MYPY:
    class IAppListArgsDict(TypedDict):
        encrypted: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
        value: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
elif False:
    IAppListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IAppListArgs:
    def __init__(__self__, *,
                 encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] encrypted: Name of origin
        :param pulumi.Input[_builtins.str] value: Name of origin
        """
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encrypted", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class IAppMetadataArgsDict(TypedDict):
        persists: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
        value: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
elif False:
    IAppMetadataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IAppMetadataArgs:
    def __init__(__self__, *,
                 persists: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] persists: Name of origin
        :param pulumi.Input[_builtins.str] value: Name of origin
        """
        if persists is not None:
            pulumi.set(__self__, "persists", persists)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def persists(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "persists")

    @persists.setter
    def persists(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "persists", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class IAppTableArgsDict(TypedDict):
        column_names: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        encrypted_columns: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of the iApp.
        """
        rows: NotRequired[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgsDict']]]]
elif False:
    IAppTableArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IAppTableArgs:
    def __init__(__self__, *,
                 column_names: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 encrypted_columns: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rows: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]] = None):
        """
        :param pulumi.Input[_builtins.str] encrypted_columns: Name of origin
        :param pulumi.Input[_builtins.str] name: Name of the iApp.
        """
        if column_names is not None:
            pulumi.set(__self__, "column_names", column_names)
        if encrypted_columns is not None:
            pulumi.set(__self__, "encrypted_columns", encrypted_columns)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @_builtins.property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "column_names")

    @column_names.setter
    def column_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "column_names", value)

    @_builtins.property
    @pulumi.getter(name="encryptedColumns")
    def encrypted_columns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted_columns")

    @encrypted_columns.setter
    def encrypted_columns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encrypted_columns", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def rows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]]:
        return pulumi.get(self, "rows")

    @rows.setter
    def rows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IAppTableRowArgs']]]]):
        pulumi.set(self, "rows", value)


if not MYPY:
    class IAppTableRowArgsDict(TypedDict):
        rows: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
elif False:
    IAppTableRowArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IAppTableRowArgs:
    def __init__(__self__, *,
                 rows: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        if rows is not None:
            pulumi.set(__self__, "rows", rows)

    @_builtins.property
    @pulumi.getter
    def rows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "rows")

    @rows.setter
    def rows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "rows", value)


if not MYPY:
    class IAppVariableArgsDict(TypedDict):
        encrypted: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of the iApp.
        """
        value: NotRequired[pulumi.Input[_builtins.str]]
        """
        Name of origin
        """
elif False:
    IAppVariableArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IAppVariableArgs:
    def __init__(__self__, *,
                 encrypted: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] encrypted: Name of origin
        :param pulumi.Input[_builtins.str] name: Name of the iApp.
        :param pulumi.Input[_builtins.str] value: Name of origin
        """
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encrypted", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the iApp.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of origin
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


