# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DeviceGroupDevice',
]

@pulumi.output_type
class DeviceGroupDevice(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "setSyncLeader":
            suggest = "set_sync_leader"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeviceGroupDevice. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeviceGroupDevice.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeviceGroupDevice.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None,
                 set_sync_leader: Optional[_builtins.bool] = None):
        """
        :param _builtins.str name: Is the name of the device Group
        :param _builtins.bool set_sync_leader: Name of origin
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if set_sync_leader is not None:
            pulumi.set(__self__, "set_sync_leader", set_sync_leader)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Is the name of the device Group
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="setSyncLeader")
    def set_sync_leader(self) -> Optional[_builtins.bool]:
        """
        Name of origin
        """
        return pulumi.get(self, "set_sync_leader")


